pub library

Constants

api → const Null
Annotates a compute normally performed by autogenerated tests to indicate it is not intended to be performed because it is actually API that is named like a test.
dir → const Null
Annotates API only usable within its enclosing directory, recursively including subdirectories.
dirtyp → const Null
dir with the additional constraint that the API is only usable within subtypes.
err → const Null
Annotates API that can throw except those that only throw objects of type Error. Those are ignored because they only throw due to code correctness errors and not errors intended to be recovered from.
fil → const Null
Annotates API only usable within its enclosing file.
filtyp → const Null
fil with the additional constraint that the API is only usable within subtypes.
pub → const Null
Annotates API usable anywhere.
pubtyp → const Null
pub with the additional constraint that the API is only usable within subtypes.
src → const Null
Annotates API only usable within its enclosing package, with one exception 1. A package is the first ancestor directory of the API which contains a pubspec.yaml file and recursively includes subdirectories which do not have a pubspec.yaml file.
srctyp → const Null
src with the additional constraint that the API is only usable within subtypes.

Functions

$(void compute()) → void
Performs compute if and only if asserts are enabled. Useful for debug-time computes that are not necessary in production and would only introduce overhead e.g. invariant checking or debug logging.
impossible(String assumptionViolations) → Never
Alias of throw Impossibility(assumptionViolations).

Exceptions / Errors

Impossibility
Thrown by a step of a computation that must never be performed.