err top-level constant

  1. @pub
Null const err

Annotates API that can throw except those that only throw objects of type Error. Those are ignored because they only throw due to code correctness errors and not errors intended to be recovered from.

Implementation

@pub const Null err=null;