src top-level constant

  1. @pub
Null const src

Annotates API only usable within its enclosing package, with one exception 1. A package is the first ancestor directory of the API which contains a pubspec.yaml file and recursively includes subdirectories which do not have a pubspec.yaml file.

1 the bootstrap package of a Dart analysis-server plugin is treated as being a part of its outer package because it is intended act as an entry point for code in the outer package.

Implementation

@pub const Null src=null;