Annotates a compute normally performed by autogenerated tests
to indicate it is not intended to be performed because it is
actually API that is named like a test.
Annotates API that can throw except those that only throw
objects of type Error. Those are ignored because they only
throw due to code correctness errors and not errors intended to
be recovered from.
Annotates API only usable within its enclosing package, with
one exception 1. A package is the first ancestor directory of
the API which contains a pubspec.yaml file and recursively
includes subdirectories which do not have a pubspec.yaml
file.
Performs compute if and only if asserts are enabled. Useful
for debug-time computes that are not necessary in production
and would only introduce overhead e.g. invariant checking or
debug logging.