api top-level constant
Annotates a compute normally performed by autogenerated tests to indicate it is not intended to be performed because it is actually API that is named like a test.
String testString()=>
'test'
testString is prefixed with test and therefore seems like a
test function and it will be performed by autogenerated tests.
However, it is intended to be API. Applying api as an
annotation to testString will prevent it from being performed
in such tests.
@api String testString()=>
'test'
Implementation
@pub const Null api=null;